%global apiversion 0.1
%global major 1
%define libname %mklibname abw %major
%define devname %mklibname -d abw

Name: libabw
Version: 0.1.1
Release: %mkrel 7
Summary: A library for import of AbiWord files
Group: System/Libraries
License: MPLv2.0
URL: https://wiki.documentfoundation.org/DLP/Libraries/libabw
Source: http://dev-www.libreoffice.org/src/%{name}/%{name}-%{version}.tar.xz
BuildRequires: boost-devel
BuildRequires: doxygen
BuildRequires: gperf
BuildRequires: help2man
BuildRequires: pkgconfig(librevenge-0.0)
BuildRequires: pkgconfig(libxml-2.0)

Patch0: 0001-coverity-1259904-dereference-before-null-check.patch
Patch1: 0001-coverity-1259905-do-not-let-AbiDocument-parse-throw.patch

%description
%{name} is a library for import of AbiWord files.

%package -n %libname
Summary: A library for import of AbiWord files
Group: System/Libraries

%description -n %libname
The %{libname} package contains libraries and header files for
developing applications that use %{name}.

%package -n %devname
Summary: Development files for %{name}
Group: Development/C
Requires: %{libname} = %{version}-%{release}
Provides: libabw-devel

%description -n %devname
The %{devname} package contains libraries and header files for
developing applications that use %{name}.

%package doc
Summary: Documentation of %{name} API
Group: Documentation
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}.

%package tools
Summary: Tools to transform AbiWord files into other formats
Group: Office/Utilities
Requires: %{libname} = %{version}

%description tools
Tools to transform AbiWord files into other formats. Currently
supported: XHTML, raw, text.

%prep
%autosetup -p1

%build
# rhbz#1258125 fix build with boost 1.59
export CPPFLAGS='-DBOOST_ERROR_CODE_HEADER_ONLY -DBOOST_SYSTEM_NO_DEPRECATED'
%configure2_5x --disable-silent-rules --disable-static --disable-werror
sed -i \
    -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    libtool
%make

export LD_LIBRARY_PATH=`pwd`/src/lib/.libs${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
help2man -N -n 'debug the conversion library' -o abw2raw.1 ./src/conv/raw/.libs/abw2raw
help2man -N -n 'convert AbiWord document into HTML' -o abw2html.1 ./src/conv/html/.libs/abw2html
help2man -N -n 'convert AbiWord document into plain text' -o abw2text.1 ./src/conv/text/.libs/abw2text

%install
%makeinstall_std
rm -f %{buildroot}/%{_libdir}/*.la
# we install API docs directly from build
rm -rf %{buildroot}/%{_docdir}/%{name}

mkdir -p %{buildroot}/%{_mandir}/man1
install -m 0644 abw2*.1 %{buildroot}/%{_mandir}/man1

%files -n %libname
%doc CREDITS README
%license COPYING.MPL 
%{_libdir}/%{name}-%{apiversion}.so.%{major}{,.*}

%files -n %devname
%doc ChangeLog
%{_includedir}/%{name}-%{apiversion}
%{_libdir}/%{name}-%{apiversion}.so
%{_libdir}/pkgconfig/%{name}-%{apiversion}.pc

%files doc
%license COPYING.MPL 
%doc docs/doxygen/html

%files tools
%{_bindir}/abw2raw
%{_bindir}/abw2text
%{_bindir}/abw2html
%{_mandir}/man1/abw2raw.1*
%{_mandir}/man1/abw2text.1*
%{_mandir}/man1/abw2html.1*


%changelog
* Mon Sep 19 2016 tv <tv> 0.1.1-7.mga6
+ Revision: 1054204
- add man pages
- coverity fixes
- drop BR on libpwd
- use pkgconfig style for libxml2 BR

* Fri Dec 25 2015 tv <tv> 0.1.1-5.mga6
+ Revision: 914719
- rebuild for new boost 1.60

* Fri Sep 25 2015 tv <tv> 0.1.1-4.mga6
+ Revision: 883498
- rebuild for new boost
- fix build with boost 1.59

* Wed Aug 26 2015 tv <tv> 0.1.1-3.mga6
+ Revision: 869827
- rebuild with gcc5

* Sun Feb 01 2015 tv <tv> 0.1.1-2.mga5
+ Revision: 812971
- submit to core/release

* Sat Jan 31 2015 tv <tv> 0.1.1-1.mga5
+ Revision: 812816
- new release

* Wed Oct 15 2014 umeabot <umeabot> 0.1.0-3.mga5
+ Revision: 750835
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.1.0-2.mga5
+ Revision: 681317
- Mageia 5 Mass Rebuild

* Thu Jul 31 2014 tv <tv> 0.1.0-1.mga5
+ Revision: 658617
- fix abi
- bump major
- BR librevenge
- new release

* Wed Feb 19 2014 tv <tv> 0.0.2-1.mga5
+ Revision: 594985
- new release

* Fri Feb 07 2014 fwang <fwang> 0.0.1-3.mga5
+ Revision: 584979
- fix requires

* Thu Feb 06 2014 tv <tv> 0.0.1-2.mga5
+ Revision: 584324
- add devel provides
- fix %%description

* Thu Feb 06 2014 tv <tv> 0.0.1-1.mga5
+ Revision: 584273
- imported package libabw

